@@ -5,7 +5,7 @@
  * object level logging, and fully-qualified object names for all DML and DDL
  * statements where possible (See README.md for details).
  *
- * Copyright (c) 2014-2022, PostgreSQL Global Development Group
+ * Copyright (c) 2014-2023, PostgreSQL Global Development Group
  *------------------------------------------------------------------------------
  */
 #include "postgres.h"
@@ -28,6 +28,7 @@
 #include "libpq/auth.h"
 #include "nodes/nodes.h"
 #include "nodes/params.h"
+#include "parser/parse_relation.h"
 #include "tcop/utility.h"
 #include "tcop/deparse_utility.h"
 #include "utils/acl.h"
@@ -135,6 +136,17 @@ bool auditLogParameter = false;
  */
 bool auditLogRelation = false;
 
+/*
+ * GUC variable for pgaudit.log_parameter_max_size
+ *
+ * Administrators can choose to prevent the logging of large variable-length
+ * parameters.  If set to 0 (the default), all parameters are logged.  If set
+ * greater than 0, variable length parameters (before character output) whose
+ * size is greater than the specified number of bytes will be replaced
+ * by a placeholder.
+*/
+int auditLogParameterMaxSize = 0;
+
 /*
  * GUC variable for pgaudit.log_rows
  *
@@ -156,7 +168,7 @@ bool auditLogStatement = true;
  * Administrators can choose to have the statement run logged only once instead
  * of on every line.  By default, the statement is repeated on every line of
  * the audit log to facilitate searching, but this can cause the log to be
- * unnecessairly bloated in some environments.
+ * unnecessarily bloated in some environments.
  */
 bool auditLogStatementOnce = false;
 
@@ -238,6 +250,8 @@ typedef struct
     MemoryContext queryContext; /* Context for query tracking rows */
     Oid auditOid;               /* Role running query tracking rows  */
     List *rangeTabls;           /* Tables in query tracking rows */
+    List *permInfos;            /* Permission info rows for each table involved
+                                   in the query */
 } AuditEvent;
 
 /*
@@ -539,13 +553,15 @@ log_audit_event(AuditEventStackItem *stackItem)
             /* Identify role statements */
             switch (stackItem->auditEvent.commandTag)
             {
-                /* In the case of create and alter role redact all text in the
+                /* In the case of create and alter role or user mapping redact all text in the
                  * command after the password token for security.  This doesn't
                  * cover all possible cases where passwords can be leaked but
                  * should take care of the most common usage.
                  */
                 case T_CreateRoleStmt:
                 case T_AlterRoleStmt:
+				case T_CreateUserMappingStmt:
+				case T_AlterUserMappingStmt:
 
                     if (stackItem->auditEvent.commandText != NULL)
                     {
@@ -704,7 +720,7 @@ log_audit_event(AuditEventStackItem *stackItem)
     append_valid_csv(&auditStr, stackItem->auditEvent.objectName);
 
     /*
-     * If auditLogStatmentOnce is true, then only log the statement and
+     * If auditLogStatementOnce is true, then only log the statement and
      * parameters if they have not already been logged for this substatement.
      */
     appendStringInfoCharMacro(&auditStr, ',');
@@ -734,7 +750,6 @@ log_audit_event(AuditEventStackItem *stackItem)
                 ParamExternData *prm = &paramList->params[paramIdx];
                 Oid typeOutput;
                 bool typeIsVarLena;
-                char *paramStr;
 
                 /* Add a comma for each param */
                 if (paramIdx != 0)
@@ -744,12 +759,27 @@ log_audit_event(AuditEventStackItem *stackItem)
                 if (prm->isnull || !OidIsValid(prm->ptype))
                     continue;
 
-                /* Output the string */
+                /*
+                 * Append the param, suppressing long params if the appropriate
+                 * GUC is set.
+                 */
                 getTypeOutputInfo(prm->ptype, &typeOutput, &typeIsVarLena);
-                paramStr = OidOutputFunctionCall(typeOutput, prm->value);
 
-                append_valid_csv(&paramStrResult, paramStr);
-                pfree(paramStr);
+                if (auditLogParameterMaxSize > 0 &&
+                    typeIsVarLena &&
+                    VARSIZE_ANY_EXHDR(prm->value) > auditLogParameterMaxSize)
+                {
+                    append_valid_csv(&paramStrResult,
+                                     "<long param suppressed>");
+                }
+                else
+                {
+                    char *paramStr = OidOutputFunctionCall(typeOutput,
+                                                           prm->value);
+
+                    append_valid_csv(&paramStrResult, paramStr);
+                    pfree(paramStr);
+                }
             }
 
             if (numParams == 0)
@@ -951,7 +981,7 @@ audit_on_any_attribute(Oid relOid,
                        AclMode mode)
 {
     bool result = false;
-    AttrNumber col;
+    AttrNumber index = -1;
     Bitmapset *tmpSet;
 
     /* If bms is empty then check for any column match */
@@ -980,9 +1010,9 @@ audit_on_any_attribute(Oid relOid,
     tmpSet = bms_copy(attributeSet);
 
     /* Check each column */
-    while ((col = bms_first_member(tmpSet)) >= 0)
+    while ((index = bms_next_member(tmpSet, index)) >= 0)
     {
-        col += FirstLowInvalidHeapAttributeNumber;
+        const AttrNumber col = index + FirstLowInvalidHeapAttributeNumber;
 
         if (col != InvalidAttrNumber &&
             audit_on_attribute(relOid, col, auditOid, mode))
@@ -1001,7 +1031,7 @@ audit_on_any_attribute(Oid relOid,
  * Create AuditEvents for SELECT/DML operations via executor permissions checks.
  */
 static void
-log_select_dml(Oid auditOid, List *rangeTabls)
+log_select_dml(Oid auditOid, List *rangeTabls, List *permInfos)
 {
     ListCell *lr;
     bool first = true;
@@ -1016,17 +1046,24 @@ log_select_dml(Oid auditOid, List *rangeTabls)
         Oid relOid;
         Oid relNamespaceOid;
         RangeTblEntry *rte = lfirst(lr);
+        const RTEPermissionInfo *perminfo;
 
-        /* We only care about tables, and can ignore subqueries etc. */
-        if (rte->rtekind != RTE_RELATION)
+        /*
+         * We only care about tables/views, which have perminfoindex set. This
+         * excludes table partitions, which do not have perminfoindex set.
+         */
+        if (rte->perminfoindex == 0)
             continue;
 
+        Assert(rte->rtekind == RTE_RELATION ||
+               (rte->rtekind == RTE_SUBQUERY && rte->relkind == RELKIND_VIEW));
+
         found = true;
 
         /*
          * Don't log if the session user is not a member of the current
          * role.  This prevents contents of security definer functions
-         * from being logged and supresses foreign key queries unless the
+         * from being logged and suppresses foreign key queries unless the
          * session user is the owner of the referenced table.
          */
         if (!is_member_of_role(GetSessionUserId(), GetUserId()))
@@ -1060,32 +1097,34 @@ log_select_dml(Oid auditOid, List *rangeTabls)
         }
 
         /*
-         * We don't have access to the parsetree here, so we have to generate
+         * We don't have access to the parse tree here, so we have to generate
          * the node type, object type, and command tag by decoding
          * rte->requiredPerms and rte->relkind. For updates we also check
          * rellockmode so that only true UPDATE commands (not
          * SELECT FOR UPDATE, etc.) are logged as UPDATE.
          */
-        if (rte->requiredPerms & ACL_INSERT)
+        perminfo = getRTEPermissionInfo(permInfos, rte);
+
+        if (perminfo->requiredPerms & ACL_INSERT)
         {
             auditEventStack->auditEvent.logStmtLevel = LOGSTMT_MOD;
             auditEventStack->auditEvent.commandTag = T_InsertStmt;
             auditEventStack->auditEvent.command = CMDTAG_INSERT;
         }
-        else if (rte->requiredPerms & ACL_UPDATE &&
+        else if (perminfo->requiredPerms & ACL_UPDATE &&
                  rte->rellockmode >= RowExclusiveLock)
         {
             auditEventStack->auditEvent.logStmtLevel = LOGSTMT_MOD;
             auditEventStack->auditEvent.commandTag = T_UpdateStmt;
             auditEventStack->auditEvent.command = CMDTAG_UPDATE;
         }
-        else if (rte->requiredPerms & ACL_DELETE)
+        else if (perminfo->requiredPerms & ACL_DELETE)
         {
             auditEventStack->auditEvent.logStmtLevel = LOGSTMT_MOD;
             auditEventStack->auditEvent.commandTag = T_DeleteStmt;
             auditEventStack->auditEvent.command = CMDTAG_DELETE;
         }
-        else if (rte->requiredPerms & ACL_SELECT)
+        else if (perminfo->requiredPerms & ACL_SELECT)
         {
             auditEventStack->auditEvent.logStmtLevel = LOGSTMT_ALL;
             auditEventStack->auditEvent.commandTag = T_SelectStmt;
@@ -1150,7 +1189,7 @@ log_select_dml(Oid auditOid, List *rangeTabls)
         {
             AclMode auditPerms =
                 (ACL_SELECT | ACL_UPDATE | ACL_INSERT | ACL_DELETE) &
-                rte->requiredPerms;
+                perminfo->requiredPerms;
 
             /*
              * If any of the required permissions for the relation are granted
@@ -1171,7 +1210,7 @@ log_select_dml(Oid auditOid, List *rangeTabls)
                 if (auditPerms & ACL_SELECT)
                     auditEventStack->auditEvent.granted =
                         audit_on_any_attribute(relOid, auditOid,
-                                               rte->selectedCols,
+                                               perminfo->selectedCols,
                                                ACL_SELECT);
 
                 /*
@@ -1181,7 +1220,7 @@ log_select_dml(Oid auditOid, List *rangeTabls)
                     auditPerms & ACL_INSERT)
                     auditEventStack->auditEvent.granted =
                         audit_on_any_attribute(relOid, auditOid,
-                                               rte->insertedCols,
+                                               perminfo->insertedCols,
                                                auditPerms);
 
                 /*
@@ -1191,7 +1230,7 @@ log_select_dml(Oid auditOid, List *rangeTabls)
                     auditPerms & ACL_UPDATE)
                     auditEventStack->auditEvent.granted =
                         audit_on_any_attribute(relOid, auditOid,
-                                               rte->updatedCols,
+                                               perminfo->updatedCols,
                                                auditPerms);
             }
         }
@@ -1372,7 +1411,7 @@ pgaudit_ExecutorStart_hook(QueryDesc *queryDesc, int eflags)
  * Hook ExecutorCheckPerms to do session and object auditing for DML.
  */
 static bool
-pgaudit_ExecutorCheckPerms_hook(List *rangeTabls, bool abort)
+pgaudit_ExecutorCheckPerms_hook(List *rangeTabls, List *permInfos, bool abort)
 {
     Oid auditOid;
 
@@ -1397,7 +1436,7 @@ pgaudit_ExecutorCheckPerms_hook(List *rangeTabls, bool abort)
                  * The SELECT event for CREATE TABLE AS will be logged
                  * in pgaudit_ExecutorEnd_hook() later to get rows.
                  */
-                log_select_dml(auditOid, rangeTabls);
+                log_select_dml(auditOid, rangeTabls, permInfos);
             }
             else
             {
@@ -1407,15 +1446,16 @@ pgaudit_ExecutorCheckPerms_hook(List *rangeTabls, bool abort)
                  */
                 auditEventStack->auditEvent.auditOid = auditOid;
                 auditEventStack->auditEvent.rangeTabls = rangeTabls;
+                auditEventStack->auditEvent.permInfos = permInfos;
             }
         }
         else
-            log_select_dml(auditOid, rangeTabls);
+            log_select_dml(auditOid, rangeTabls, permInfos);
     }
 
     /* Call the next hook function */
     if (next_ExecutorCheckPerms_hook &&
-        !(*next_ExecutorCheckPerms_hook) (rangeTabls, abort))
+        !(*next_ExecutorCheckPerms_hook) (rangeTabls, permInfos, abort))
         return false;
 
     return true;
@@ -1468,7 +1508,8 @@ pgaudit_ExecutorEnd_hook(QueryDesc *queryDesc)
 
             /* Log SELECT/DML audit entry */
             log_select_dml(stackItem->auditEvent.auditOid,
-                           stackItem->auditEvent.rangeTabls);
+                           stackItem->auditEvent.rangeTabls,
+                           stackItem->auditEvent.permInfos);
 
             /* Switch back to the previous auditEventStack */
             auditEventStack = auditEventStackFull;
@@ -1860,7 +1901,7 @@ check_pgaudit_log(char **newVal, void **extra, GucSource source)
      * Check that we recognise each token, and add it to the bitmap we're
      * building up in a newly-allocated int *f.
      */
-    if (!(flags = (int *) malloc(sizeof(int))))
+    if (!(flags = (int *)guc_malloc(FATAL, sizeof(int))))
         return false;
 
     *flags = 0;
@@ -1899,7 +1940,7 @@ check_pgaudit_log(char **newVal, void **extra, GucSource source)
             class = LOG_WRITE;
         else
         {
-            free(flags);
+            guc_free(flags);
             pfree(rawVal);
             list_free(flagRawList);
             return false;
@@ -1944,7 +1985,7 @@ check_pgaudit_log_level(char **newVal, void **extra, GucSource source)
     int *logLevel;
 
     /* Allocate memory to store the log level */
-    if (!(logLevel = (int *) malloc(sizeof(int))))
+    if (!(logLevel = (int *)guc_malloc(FATAL, sizeof(int))))
         return false;
 
     /* Find the log level enum */
@@ -1972,7 +2013,7 @@ check_pgaudit_log_level(char **newVal, void **extra, GucSource source)
     /* Error if the log level enum is not found */
     else
     {
-        free(logLevel);
+        guc_free(logLevel);
         return false;
     }
 
@@ -2094,6 +2135,26 @@ _PG_init(void)
         GUC_NOT_IN_SAMPLE,
         NULL, NULL, NULL);
 
+    /* Define pgaudit.log_parameter_max_size */
+    DefineCustomIntVariable(
+        "pgaudit.log_parameter_max_size",
+
+        "Specifies, in bytes, the maximum length of variable-length parameters "
+        "to log.  If 0 (the default), parameters are not checked for size.  If "
+        "set, when the size of the parameter is longer than the setting, the "
+        "value in the audit log is replaced with a placeholder. Note that for "
+        "character types, the length is in bytes for the parameter's encoding, "
+        "not characters.",
+
+        NULL,
+        &auditLogParameterMaxSize,
+        0,
+        0,
+        (1 << 30) - 1,
+        PGC_SUSET,
+        GUC_NOT_IN_SAMPLE,
+        NULL, NULL, NULL);
+
     /* Define pgaudit.log_relation */
     DefineCustomBoolVariable(
         "pgaudit.log_relation",
