@@ -49,23 +49,23 @@ ALTER ROLE :current_user SET pgaudit.log_client = ON;
 
 --
 -- Create auditor role
-CREATE ROLE regress_auditor;
+CREATE ROLE auditor;
 
 --
 -- Create first test user
-CREATE USER regress_user1 password 'password';
-ALTER ROLE regress_user1 SET pgaudit.log = 'ddl, ROLE';
-ALTER ROLE regress_user1 SET pgaudit.log_level = 'notice';
+CREATE USER user1 password 'password';
+ALTER ROLE user1 SET pgaudit.log = 'ddl, ROLE';
+ALTER ROLE user1 SET pgaudit.log_level = 'notice';
 
-ALTER ROLE regress_user1 PassWord 'password2' NOLOGIN;
-ALTER USER regress_user1 encrypted /* random comment */PASSWORD
+ALTER ROLE user1 PassWord 'password2' NOLOGIN;
+ALTER USER user1 encrypted /* random comment */PASSWORD
 	/* random comment */
     'md565cb1da342495ea6bb0418a6e5718c38' LOGIN;
-ALTER ROLE regress_user1 SET pgaudit.log_client = ON;
+ALTER ROLE user1 SET pgaudit.log_client = ON;
 
 --
 -- Create, select, drop (select will not be audited)
-\connect - regress_user1
+\connect - user1
 
 CREATE TABLE public.test
 (
@@ -81,13 +81,13 @@ DROP TABLE test;
 -- Create second test user
 \connect - :current_user
 
-CREATE ROLE regress_user2 LOGIN password 'password';
-ALTER ROLE regress_user2 SET pgaudit.log = 'Read, writE';
-ALTER ROLE regress_user2 SET pgaudit.log_catalog = OFF;
-ALTER ROLE regress_user2 SET pgaudit.log_client = ON;
-ALTER ROLE regress_user2 SET pgaudit.log_level = 'warning';
-ALTER ROLE regress_user2 SET pgaudit.role = regress_auditor;
-ALTER ROLE regress_user2 SET pgaudit.log_statement_once = ON;
+CREATE ROLE user2 LOGIN password 'password';
+ALTER ROLE user2 SET pgaudit.log = 'Read, writE';
+ALTER ROLE user2 SET pgaudit.log_catalog = OFF;
+ALTER ROLE user2 SET pgaudit.log_client = ON;
+ALTER ROLE user2 SET pgaudit.log_level = 'warning';
+ALTER ROLE user2 SET pgaudit.role = auditor;
+ALTER ROLE user2 SET pgaudit.log_statement_once = ON;
 
 --
 -- Setup role-based tests
@@ -98,11 +98,11 @@ CREATE TABLE test2
 
 GRANT SELECT, INSERT, UPDATE, DELETE
    ON test2
-   TO regress_user2, regress_user1;
+   TO user2, user1;
 
 GRANT SELECT, UPDATE
    ON TABLE public.test2
-   TO regress_auditor;
+   TO auditor;
 
 CREATE TABLE test3
 (
@@ -111,11 +111,11 @@ CREATE TABLE test3
 
 GRANT SELECT, INSERT, UPDATE, DELETE
    ON test3
-   TO regress_user2;
+   TO user2;
 
 GRANT INSERT
    ON TABLE public.test3
-   TO regress_auditor;
+   TO auditor;
 
 CREATE FUNCTION test2_insert() RETURNS TRIGGER AS $$
 BEGIN
@@ -125,7 +125,7 @@ BEGIN
 
 	RETURN new;
 END $$ LANGUAGE plpgsql security definer;
-ALTER FUNCTION test2_insert() OWNER TO regress_user1;
+ALTER FUNCTION test2_insert() OWNER TO user1;
 
 CREATE TRIGGER test2_insert_trg
 	AFTER INSERT ON test2
@@ -137,7 +137,7 @@ BEGIN
 	   SET id = id + 1
 	 WHERE id = change_id;
 END $$ LANGUAGE plpgsql security definer;
-ALTER FUNCTION test2_change(int) OWNER TO regress_user2;
+ALTER FUNCTION test2_change(int) OWNER TO user2;
 
 CREATE VIEW vw_test3 AS
 SELECT *
@@ -145,13 +145,13 @@ SELECT *
 
 GRANT SELECT
    ON vw_test3
-   TO regress_user2;
+   TO user2;
 
 GRANT SELECT
    ON vw_test3
-   TO regress_auditor;
+   TO auditor;
 
-\connect - regress_user2
+\connect - user2
 
 --
 -- Role-based tests
@@ -237,9 +237,9 @@ SELECT *
 --
 -- Change permissions of user 2 so that only object logging will be done
 \connect - :current_user
-ALTER ROLE regress_user2 SET pgaudit.log = 'NONE';
+ALTER ROLE user2 SET pgaudit.log = 'NONE';
 
-\connect - regress_user2
+\connect - user2
 
 --
 -- Create test4 and add permissions
@@ -251,15 +251,15 @@ CREATE TABLE test4
 
 GRANT SELECT (name)
    ON TABLE public.test4
-   TO regress_auditor;
+   TO auditor;
 
 GRANT UPDATE (id)
    ON TABLE public.test4
-   TO regress_auditor;
+   TO auditor;
 
 GRANT insert (name)
    ON TABLE public.test4
-   TO regress_auditor;
+   TO auditor;
 
 --
 -- Not object logged
@@ -304,10 +304,10 @@ update public.test4 set name = 'foo' where name = 'bar';
 -- Confirm that "long" parameter values will not be logged if pgaudit.log_parameter_max_size
 -- is set.
 \connect - :current_user
-ALTER ROLE regress_user2 SET pgaudit.log_parameter_max_size = 50;
-ALTER ROLE regress_user2 SET pgaudit.log_parameter = 'on';
+ALTER ROLE user2 SET pgaudit.log_parameter_max_size = 50;
+ALTER ROLE user2 SET pgaudit.log_parameter = 'on';
 
-\connect - regress_user2
+\connect - user2
 PREPARE testinsert(int, text) AS
     INSERT INTO test4 VALUES($1, $2);
 
@@ -316,9 +316,9 @@ EXECUTE testinsert(1, '*******************************************************')
 DEALLOCATE testinsert;
 
 \connect - :current_user
-ALTER ROLE regress_user2 RESET pgaudit.log_parameter_max_size;
+ALTER ROLE user2 RESET pgaudit.log_parameter_max_size;
 
-\connect - regress_user2
+\connect - user2
 PREPARE testinsert(int, text) AS
     INSERT INTO test4 VALUES($1, $2);
 
@@ -327,7 +327,7 @@ EXECUTE testinsert(2, '*******************************************************')
 DEALLOCATE testinsert;
 
 \connect - :current_user
-ALTER ROLE regress_user2 RESET pgaudit.log_parameter;
+ALTER ROLE user2 RESET pgaudit.log_parameter;
 
 --
 -- Change permissions of user 1 so that session logging will be done
@@ -342,8 +342,8 @@ DROP TABLE test4;
 DROP FUNCTION test2_insert();
 DROP FUNCTION test2_change(int);
 
-ALTER ROLE regress_user1 SET pgaudit.log = 'DDL, READ';
-\connect - regress_user1
+ALTER ROLE user1 SET pgaudit.log = 'DDL, READ';
+\connect - user1
 
 --
 -- Create table is session logged
@@ -363,21 +363,21 @@ SELECT *
 --
 -- Insert is not logged
 INSERT INTO account (id, name, password, description)
-			 VALUES (1, 'regress_user1', 'HASH1', 'blah, blah');
+			 VALUES (1, 'user1', 'HASH1', 'blah, blah');
 
 --
 -- Change permissions of user 1 so that only object logging will be done
 \connect - :current_user
-ALTER ROLE regress_user1 SET pgaudit.log = 'none';
-ALTER ROLE regress_user1 SET pgaudit.role = 'regress_auditor';
-\connect - regress_user1
+ALTER ROLE user1 SET pgaudit.log = 'none';
+ALTER ROLE user1 SET pgaudit.role = 'auditor';
+\connect - user1
 
 --
--- ROLE class not set, so regress_auditor grants not logged
+-- ROLE class not set, so auditor grants not logged
 GRANT SELECT (password),
 	  UPDATE (name, password)
    ON TABLE public.account
-   TO regress_auditor;
+   TO auditor;
 
 --
 -- Not object logged
@@ -405,9 +405,9 @@ UPDATE account
 --
 -- Change permissions of user 1 so that session relation logging will be done
 \connect - :current_user
-ALTER ROLE regress_user1 SET pgaudit.log_relation = on;
-ALTER ROLE regress_user1 SET pgaudit.log = 'read, WRITE';
-\connect - regress_user1
+ALTER ROLE user1 SET pgaudit.log_relation = on;
+ALTER ROLE user1 SET pgaudit.log = 'read, WRITE';
+\connect - user1
 
 --
 -- Not logged
@@ -418,10 +418,10 @@ CREATE TABLE ACCOUNT_ROLE_MAP
 );
 
 --
--- ROLE class not set, so regress_auditor grants not logged
+-- ROLE class not set, so auditor grants not logged
 GRANT SELECT
    ON TABLE public.account_role_map
-   TO regress_auditor;
+   TO auditor;
 
 --
 -- Object logged because of:
@@ -474,10 +474,10 @@ UPDATE account
 --
 -- Change configuration of user 1 so that full statements are not logged
 \connect - :current_user
-ALTER ROLE regress_user1 RESET pgaudit.log_relation;
-ALTER ROLE regress_user1 RESET pgaudit.log;
-ALTER ROLE regress_user1 SET pgaudit.log_statement = OFF;
-\connect - regress_user1
+ALTER ROLE user1 RESET pgaudit.log_relation;
+ALTER ROLE user1 RESET pgaudit.log;
+ALTER ROLE user1 SET pgaudit.log_statement = OFF;
+\connect - user1
 
 --
 -- Logged but without full statement
@@ -516,7 +516,7 @@ SELECT *
 --
 -- Copy from stdin to account copy
 COPY test.account_copy from stdin;
-1	regress_user1	HASH2	yada, yada
+1	user1	HASH2	yada, yada
 \.
 
 --
@@ -710,15 +710,15 @@ DROP DATABASE contrib_regression_pgaudit2;
 SET pgaudit.log = 'ROLE';
 
 CREATE TABLE t ();
-CREATE ROLE regress_alice;
+CREATE ROLE alice;
 
 CREATE SCHEMA foo2
 	GRANT SELECT
 	   ON public.t
-	   TO regress_alice;
+	   TO alice;
 
 drop table public.t;
-drop role regress_alice;
+drop role alice;
 
 --
 -- Test for non-empty stack error
@@ -764,7 +764,7 @@ SELECT test();
 --
 -- Delete all rows then delete 1 row
 SET pgaudit.log = 'write';
-SET pgaudit.role = 'regress_auditor';
+SET pgaudit.role = 'auditor';
 
 create table bar
 (
@@ -773,7 +773,7 @@ create table bar
 
 grant delete
    on bar
-   to regress_auditor;
+   to auditor;
 
 insert into bar (col)
 		 values (1);
@@ -789,13 +789,13 @@ drop table bar;
 --
 -- Grant roles to each other
 SET pgaudit.log = 'role';
-GRANT regress_user1 TO regress_user2;
-REVOKE regress_user1 FROM regress_user2;
+GRANT user1 TO user2;
+REVOKE user1 FROM user2;
 
 --
 -- Test that FK references do not log but triggers still do
 SET pgaudit.log = 'READ,WRITE';
-SET pgaudit.role TO 'regress_auditor';
+SET pgaudit.role TO 'auditor';
 
 CREATE TABLE aaa
 (
@@ -821,11 +821,11 @@ CREATE TRIGGER bbb_insert_trg
 
 GRANT SELECT, UPDATE
    ON aaa
-   TO regress_auditor;
+   TO auditor;
 
 GRANT UPDATE
    ON bbb
-   TO regress_auditor;
+   TO auditor;
 
 INSERT INTO aaa VALUES (generate_series(1,100));
 
@@ -853,9 +853,9 @@ SET pgaudit.log_client = ON;
 SET pgaudit.log_relation = ON;
 SET pgaudit.log_parameter = ON;
 
-CREATE ROLE regress_alice;
+CREATE ROLE alice;
 
-SET ROLE regress_alice;
+SET ROLE alice;
 CREATE TABLE t (a int, b text);
 SET search_path TO test, public;
 
@@ -868,7 +868,7 @@ RESET ROLE;
 -- Test MISC_SET
 SET pgaudit.log = 'MISC_SET';
 
-SET ROLE regress_alice;
+SET ROLE alice;
 SET search_path TO public;
 
 INSERT INTO t VALUES (2, 'misc_set');
@@ -888,7 +888,7 @@ VACUUM t;
 
 RESET ROLE;
 DROP TABLE public.t;
-DROP ROLE regress_alice;
+DROP ROLE alice;
 
 --
 -- Test PARTITIONED table
@@ -1051,7 +1051,7 @@ DROP FUNCTION test2_change(int);
 --
 -- Only object logging will be done
 SET pgaudit.log = 'none';
-SET pgaudit.role = 'regress_auditor';
+SET pgaudit.role = 'auditor';
 
 --
 -- Select is session logged
@@ -1061,7 +1061,7 @@ SELECT *
 --
 -- Insert is not logged
 INSERT INTO account (id, name, password, description)
-			 VALUES (1, 'regress_user2', 'HASH3', 'blah, blah2');
+			 VALUES (1, 'user2', 'HASH3', 'blah, blah2');
 INSERT INTO account (id, name, password, description)
 			 VALUES (1, 'user3', 'HASH4', 'blah, blah3');
 
@@ -1164,7 +1164,7 @@ SELECT *
 --
 -- Copy from stdin to account copy
 COPY test.account_copy from stdin;
-1	regress_user1	HASH4	yada, yada4
+1	user1	HASH4	yada, yada4
 \.
 
 --
@@ -1390,15 +1390,15 @@ DROP DATABASE contrib_regression_pgaudit2;
 SET pgaudit.log = 'role';
 
 CREATE TABLE t ();
-CREATE ROLE regress_alice;
+CREATE ROLE alice;
 
 CREATE SCHEMA foo3
 	GRANT SELECT
 	   ON public.t
-	   TO regress_alice;
+	   TO alice;
 
 drop table public.t;
-drop role regress_alice;
+drop role alice;
 
 --
 -- Test for non-empty stack error
@@ -1439,7 +1439,7 @@ SELECT test1();
 --
 -- Delete all rows then delete 1 row
 SET pgaudit.log = 'write';
-SET pgaudit.role = 'regress_auditor';
+SET pgaudit.role = 'auditor';
 
 create table bar
 (
@@ -1448,7 +1448,7 @@ create table bar
 
 grant delete
    on bar
-   to regress_auditor;
+   to auditor;
 
 insert into bar (col)
 		 values (1);
@@ -1464,7 +1464,7 @@ drop table bar;
 --
 -- Test that FK references do not log but triggers still do
 SET pgaudit.log = 'read, write';
-SET pgaudit.role TO 'regress_auditor';
+SET pgaudit.role TO 'auditor';
 
 CREATE TABLE aaa
 (
@@ -1490,11 +1490,11 @@ CREATE TRIGGER bbb_insert_trg1
 
 GRANT SELECT, UPDATE
    ON aaa
-   TO regress_auditor;
+   TO auditor;
 
 GRANT UPDATE
    ON bbb
-   TO regress_auditor;
+   TO auditor;
 
 INSERT INTO aaa VALUES (generate_series(1,100));
 
@@ -1512,9 +1512,9 @@ SET pgaudit.log_client = on;
 SET pgaudit.log_relation = on;
 SET pgaudit.log_parameter = on;
 
-CREATE ROLE regress_alice;
+CREATE ROLE alice;
 
-SET ROLE regress_alice;
+SET ROLE alice;
 CREATE TABLE t (a int, b text);
 SET search_path TO test, public;
 
@@ -1527,7 +1527,7 @@ RESET ROLE;
 -- Test MISC_SET
 SET pgaudit.log = 'MISC_SET';
 
-SET ROLE regress_alice;
+SET ROLE alice;
 SET search_path TO public;
 
 INSERT INTO t VALUES (2, 'misc_set');
@@ -1546,7 +1546,7 @@ VACUUM t;
 
 RESET ROLE;
 DROP TABLE public.t;
-DROP ROLE regress_alice;
+DROP ROLE alice;
 
 --
 -- Test PARTITIONED table
@@ -1563,11 +1563,11 @@ DROP TABLE h;
 --
 -- Change configuration of user 1 so that full statements are not logged
 \connect - :current_user
-ALTER ROLE regress_user1 RESET pgaudit.log_relation;
-ALTER ROLE regress_user1 RESET pgaudit.log;
-ALTER ROLE regress_user1 SET pgaudit.log_statement = OFF;
-ALTER ROLE regress_user1 SET pgaudit.log_rows = on;
-\connect - regress_user1
+ALTER ROLE user1 RESET pgaudit.log_relation;
+ALTER ROLE user1 RESET pgaudit.log;
+ALTER ROLE user1 SET pgaudit.log_statement = OFF;
+ALTER ROLE user1 SET pgaudit.log_rows = on;
+\connect - user1
 
 --
 -- Logged but without full statement
@@ -1624,10 +1624,10 @@ SET pgaudit.log_level = 'notice';
 CREATE EXTENSION postgres_fdw;
 CREATE SERVER fdw_server FOREIGN DATA WRAPPER postgres_fdw OPTIONS (host 'foo', dbname 'foodb', port '5432');
 
-CREATE USER MAPPING FOR regress_user1 SERVER fdw_server OPTIONS (user 'regress_user1', password 'secret');
-ALTER USER MAPPING FOR regress_user1 SERVER fdw_server OPTIONS (SET /* comment */ password 'secret2');
+CREATE USER MAPPING FOR user1 SERVER fdw_server OPTIONS (user 'user1', password 'secret');
+ALTER USER MAPPING FOR user1 SERVER fdw_server OPTIONS (SET /* comment */ password 'secret2');
 
-DROP USER MAPPING FOR regress_user1 SERVER fdw_server;
+DROP USER MAPPING FOR user1 SERVER fdw_server;
 DROP SERVER fdw_server;
 DROP EXTENSION postgres_fdw;
 
@@ -1665,8 +1665,8 @@ DROP SCHEMA foo;
 DROP TABLE hoge;
 DROP TABLE account;
 DROP TABLE account_role_map;
-DROP USER regress_user2;
-DROP USER regress_user1;
-DROP ROLE regress_auditor;
+DROP USER user2;
+DROP USER user1;
+DROP ROLE auditor;
 
 RESET client_min_messages;
